@@ -1,7 +1,9 @@
 /******************************************************************
+ *
+ * $Id: open2300db2APRS.c,v 1.8 2010/01/31 02:12:23 we7u Exp $
  *
  * Copyright (C) 2005 Jim Chandler <jim@n0vh.org>
- * Portions Copyright (C) 2004-2008 The Xastir Group
+ * Portions Copyright (C) 2004-2010 The Xastir Group
  *
  * Portions copied from Bruce Bennett's excellent Davis WX work
  *
@@ -447,6 +449,7 @@ int Get_Latest_WX( double *winddir,
     char latest_timestamp[20];
     char query_buffer[160];
     int nrows, row_cnt, item_count;
+    int nfields;
 
 		
     // Find latest, see if it's new to us
@@ -521,8 +524,10 @@ int Get_Latest_WX( double *winddir,
         return 0;
     }
     else {
+        nfields=mysql_num_fields(result);
+        row=mysql_fetch_row(result);
         if (debug_level & 1)
-            fprintf(stderr,"info: Latest Weather Data query: number of types of readings %d\n",nrows);
+            fprintf(stderr,"info: Latest Weather Data query: number of types of readings %d\n",nfields);
     }
 
     *valid_data_flgs = 0;
