@@ -5,7 +5,7 @@
 #
 # Written 20050227 Dan Brown N8YSZ
 #
-# Copyright (C) 2000-2008  The Xastir Group
+# Copyright (C) 2000-2010  The Xastir Group
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -33,26 +33,25 @@ SHAPELIB_URL=http://dl.maptools.org/dl/shapelib/${SHAPELIB_FILE}
 
 XASDIR=$HOME/src/xastir
 XASTIR_TMP=$XASDIR/tmp
-
-XASTIR_LIB=$HOME/src/xastir/lib
+XASTIR_LIB=$XASDIR/lib
 
 
 UNAME=`uname -o`
 
 if [ $UNAME = 'Cygwin' ]
 then
-    printf "Os is %s. Skipping sudo tests.\n" $UNAME 
+    printf "OS is %s. Skipping sudo tests.\n" $UNAME 
 else 
     printf "Checking for sudo\n" 
 
     if  SUDO=`which sudo` 
     then 
-        printf "$SUDO found - validating $SUDO privilages\n" 
+        printf "$SUDO found - validating $SUDO privileges\n" 
         if $SUDO -v 
         then
             printf "Ok, we can continue\n"
         else
-            printf "ERROR: %s needs $SUDO privilages - aborting \n" $0
+            printf "ERROR: %s needs $SUDO privileges - aborting \n" $0
             exit 
         fi 
     else
@@ -80,12 +79,11 @@ fi
 
 if [ ! -d $XASTIR_TMP ]
 then
-    printf "ERROR: %s Doesn't appear to exsit.\n" $XASTIR_TMP
-    printf "Please create dir and/or edit script. Exiting\n"
-    exit 
-else 
-    cd $XASTIR_TMP
+    printf "WARNING: %s Doesn't appear to exist. Creating temporary directory\n" $XASTIR_TMP
+    # Make sure this exists!
+    mkdir -p $XASTIR_TMP
 fi
+cd $XASTIR_TMP
 
 if [ -e $SHAPELIB_FILE -o -e $SHAPELIB ]
 then
@@ -138,16 +136,36 @@ else
 
     printf "Checking /etc/ld.so.conf"
 
-    if (! grep /usr/local/lib /etc/ld.so.conf 2>&1 > /dev/null) 
-    then
-        printf "Warning: /usr/local/lib not in /etc/ld.so.conf - adding it\n"
-        cp /etc/ld.so.conf /tmp
-        printf "/usr/local/lib\n" >> /tmp/ld.so.conf
-        $SUDO cp /etc/ld.so.conf /etc/ld.so.conf.save 
-        $SUDO cp /tmp/ld.so.conf /etc/ld.so.conf
+    if [ -d /etc/ld.so.conf.d ]
+    then 
+	LDCONF_FILE=/etc/ld.so.conf.d/xastir.conf 
+    else
+	LDCONF_FILE=/etc/ld.so.conf
     fi
 
-    if ( grep /usr/local/lib /etc/ld.so.conf ) 
+    if [ ! -f $LDCONF_FILE ]
+    then 
+	sudo touch $LDCONF_FILE
+    fi
+
+    if (! grep /usr/local/lib $LDCONF_FILE 2>&1 > /dev/null) 
+    then
+        printf "Warning: /usr/local/lib not in %s - adding it\n" $LDCONF_FILE
+	if MKTEMP=`which mktemp`
+	then
+	    TMPFILE=`mktemp -t ld.so.conf.XXXXXXXXXX`
+	else
+	    TMPFILE='/tmp/ld.so.conf.XXXXXXXXXX'
+	    $SUDO rm -f $TMPFILE
+	    touch $TMPFILE
+	fi
+        cp $LDCONF_FILE $TMPFILE
+        printf "/usr/local/lib\n" >> $TMPFILE
+        $SUDO cp $LDCONF_FILE $LDCONF_FILE.save 
+        $SUDO cp $TMPFILE $LDCONF_FILE
+    fi
+
+    if ( grep /usr/local/lib $LDCONF_FILE ) 
     then
         printf "Running ldconfig\n" 
         if ($SUDO ldconfig ) 
@@ -157,7 +175,7 @@ else
             printf "ldconfig had errors - you may need to run ldconfig manually.\n" 
         fi
     else
-        printf "ERROR: could not add /usr/local/lib to /etc/ld.so.conf - aborting\n"
+        printf "ERROR: could not add /usr/local/lib to $LDCONF_FILE - aborting\n"
         exit
     fi
 fi
