@@ -1,9 +1,9 @@
 /* -*- c-basic-offset: 4; indent-tabs-mode: nil -*-
- * $Id: alert.c,v 1.107 2008/07/03 14:55:12 gstueve Exp $
+ * $Id: alert.c,v 1.112 2010/08/10 08:22:53 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2008  The Xastir Group
+ * Copyright (C) 2000-2010  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -990,8 +990,11 @@ int alert_on_screen(void) {
 //
 // SFONPW>APRS::NWS-ADVIS:WIND,CA_Z007,CA_Z065, ALAMEDA AND CON & NAPA COUNTY {JDIAA
 //
-// We also now have compressed NWS alerts, signified by NWS_ADVIS
-// (underline instead of dash).
+// We also have compressed NWS alerts, signified by NWS_ADVIS
+// (underline instead of dash).  Note that Pete Loveall, AE5PL, is
+// also sending out alerts and sending the "compressed" zone format
+// with "NWS-" which is different than how Dale Huguley was sending
+// them out.  Pete's change is to support Kenwood radios.
 //
 //
 // Expiration is then computed from the activity field.  Alert_level
@@ -1212,7 +1215,18 @@ void alert_build_list(Message *fill) {
         // Check for "NWS_" in the call_sign field.  Underline
         // signifies compressed alert format.  Dash signifies
         // non-compressed format.
-        if (strncmp(fill->call_sign,"NWS_",4) == 0) {
+//
+// TEMPORARY CHANGE:  Process all NWS_ or NWS- as compressed to
+// handle the format that Pete Loveall, AE5PL, is putting out on the
+// 'net.  The correct change would be to check inside the data
+// portion for compressed-format zones in all cases and de-compress
+// them when found.
+// WE7U.
+//
+//        if (strncmp(fill->call_sign,"NWS_",4) == 0) {
+        if (       (strncmp(fill->call_sign,"NWS_",4) == 0)
+                || (strncmp(fill->call_sign,"NWS-",4) == 0) ) {
+
             char compressed_wx[512];
             char *ptr;
 
@@ -1340,13 +1354,13 @@ if (debug_level & 2)
                 // overrunning our destination string.
                 strncat(uncompressed_wx,
                     ",",
-                    sizeof(uncompressed_wx) - strlen(uncompressed_wx));
+                    sizeof(uncompressed_wx) - 1 - strlen(uncompressed_wx));
                 strncat(uncompressed_wx,
                     prefix,
-                    sizeof(uncompressed_wx) - strlen(uncompressed_wx)); 
+                    sizeof(uncompressed_wx) - 1 - strlen(uncompressed_wx)); 
                 strncat(uncompressed_wx,
                     suffix,
-                    sizeof(uncompressed_wx) - strlen(uncompressed_wx));
+                    sizeof(uncompressed_wx) - 1 - strlen(uncompressed_wx));
                 // Terminate it every time
                 uncompressed_wx[9999] = '\0';
 
@@ -1431,13 +1445,13 @@ if (debug_level & 2)
                             // our destination string.
                             strncat(uncompressed_wx,
                                 ",",
-                                sizeof(uncompressed_wx) - strlen(uncompressed_wx));
+                                sizeof(uncompressed_wx) - 1 - strlen(uncompressed_wx));
                             strncat(uncompressed_wx,
                                 prefix,
-                                sizeof(uncompressed_wx) - strlen(uncompressed_wx)); 
+                                sizeof(uncompressed_wx) - 1 - strlen(uncompressed_wx)); 
                             strncat(uncompressed_wx,
                                 suffix,
-                                sizeof(uncompressed_wx) - strlen(uncompressed_wx));
+                                sizeof(uncompressed_wx) - 1 - strlen(uncompressed_wx));
                             // Terminate it every time
                             uncompressed_wx[9999] = '\0';
                         }
@@ -1515,13 +1529,13 @@ if (debug_level & 2)
                             // our destination string.
                             strncat(uncompressed_wx,
                                 ",",
-                                sizeof(uncompressed_wx) - strlen(uncompressed_wx));
+                                sizeof(uncompressed_wx) - 1 - strlen(uncompressed_wx));
                             strncat(uncompressed_wx,
                                 prefix,
-                                sizeof(uncompressed_wx) - strlen(uncompressed_wx)); 
+                                sizeof(uncompressed_wx) - 1 - strlen(uncompressed_wx)); 
                             strncat(uncompressed_wx,
                                 suffix,
-                                sizeof(uncompressed_wx) - strlen(uncompressed_wx));
+                                sizeof(uncompressed_wx) - 1 - strlen(uncompressed_wx));
                             // Terminate it every time
                             uncompressed_wx[9999] = '\0';
                         }
@@ -1682,7 +1696,8 @@ if (debug_level & 2)
             // an array with the various zone names.
             split_string(&uncompressed_wx[1],
                 title_ptr,
-                MAX_SUB_ALERTS);
+                MAX_SUB_ALERTS,
+                ',');
         }
         else {  // Handle non-compressed packet
             // We have up to five alerts to process.
