@@ -1,9 +1,9 @@
 /*
- * $Id: database.h,v 1.50 2008/07/30 15:24:55 we7u Exp $
+ * $Id: database.h,v 1.54 2010/01/31 02:12:23 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2008  The Xastir Group
+ * Copyright (C) 2000-2010  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -82,7 +82,8 @@ enum APRS_Types {
     APRS_MICE,
     APRS_GRID,
     DALLAS_ONE_WIRE,
-    DAVISMETEO
+    DAVISMETEO,
+    DAVISAPRSDL
 };
 
 
@@ -516,7 +517,7 @@ extern CADRow *CAD_list_head;
 #define ST_MOVING       0x08    // station is moving
 #define ST_DIRECT       0x10    // heard direct (not via digis)
 #define ST_VIATNC       0x20    // station heard via TNC
-#define ST_3RD_PT       0x40    // third party traffic (not used yet)
+#define ST_3RD_PT       0x40    // third party traffic
 #define ST_MSGCAP       0x80    // message capable (not used yet)
 #define ST_STATUS       0x100   // got real status message
 #define ST_INVIEW       0x200   // station is in current screen view
