@@ -1,9 +1,9 @@
 /*
- * $Id: hostname.c,v 1.28 2008/01/16 19:34:00 we7u Exp $
+ * $Id: hostname.c,v 1.31 2010/01/31 02:12:24 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2008  The Xastir Group
+ * Copyright (C) 2000-2010  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -246,12 +246,12 @@ char *host_lookup(char *host, char *ip, int ip_size, int time) {
                                         if (ips>0) {
                                             strncat(ip_addr,
                                                 " ",
-                                                sizeof(ip_addr) - strlen(ip_addr));
+                                                sizeof(ip_addr) - 1 - strlen(ip_addr));
                                         }
 
                                         strncat(ip_addr,
                                             temp,
-                                            sizeof(ip_addr) - strlen(ip_addr));
+                                            sizeof(ip_addr) - 1 - strlen(ip_addr));
 
                                         ips++;
                                     }
