@@ -1,9 +1,9 @@
 /*
- * $Id: locate_gui.c,v 1.27 2008/07/02 03:04:41 we7u Exp $
+ * $Id: locate_gui.c,v 1.31 2010/01/31 02:12:24 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2008  The Xastir Group
+ * Copyright (C) 2000-2010  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -198,26 +198,26 @@ void fcc_rac_lookup(Widget w, XtPointer clientData, XtPointer callData) {
                     if (my_rac_data.qual_a[0] == 'A')
                         strncat(temp,
                             langcode("STIFCC0008"),
-                            sizeof(temp) - strlen(temp));
+                            sizeof(temp) - 1 - strlen(temp));
 
                     if (my_rac_data.qual_d[0] == 'D')
                         strncat(temp,
                             langcode("STIFCC0009"),
-                            sizeof(temp) - strlen(temp));
+                            sizeof(temp) - 1 - strlen(temp));
 
                     if (my_rac_data.qual_b[0] == 'B' && my_rac_data.qual_c[0] != 'C')
                         strncat(temp,
                             langcode("STIFCC0010"),
-                            sizeof(temp) - strlen(temp));
+                            sizeof(temp) - 1 - strlen(temp));
 
                     if (my_rac_data.qual_c[0] == 'C')
                         strncat(temp,
                             langcode("STIFCC0011"),
-                            sizeof(temp) - strlen(temp));
+                            sizeof(temp) - 1 - strlen(temp));
 
                     strncat(temp,
                         "\n",
-                        sizeof(temp) - strlen(temp));
+                        sizeof(temp) - 1 - strlen(temp));
 
                     if (strlen(my_rac_data.club_name) > 1) {
                         xastir_snprintf(temp2,
@@ -230,7 +230,7 @@ void fcc_rac_lookup(Widget w, XtPointer clientData, XtPointer callData) {
                             my_rac_data.club_postal_code);
                         strncat(temp,
                             temp2,
-                            sizeof(temp) - strlen(temp));
+                            sizeof(temp) - 1 - strlen(temp));
                     }
 
 
@@ -800,18 +800,20 @@ void Locate_place_now(Widget w, XtPointer clientData, XtPointer callData) {
 
     /*fprintf(stderr,"looking for %s\n",locate_place_name);*/
 
-    match_quantity = gnis_locate_place(da,
-        locate_place_name,
-        locate_state_name,
-        locate_county_name,
-        locate_quad_name,
-        locate_type_name,
-        locate_gnis_filename,
+    match_quantity = gnis_locate_place(da, locate_place_name,
+        locate_state_name, locate_county_name, locate_quad_name,
+        locate_type_name, locate_gnis_filename,
         (int)XmToggleButtonGetState(locate_place_case_data),
         (int)XmToggleButtonGetState(locate_place_match_data),
-        match_array_name,
-        match_array_lat,
-        match_array_long);
+        match_array_name, match_array_lat, match_array_long);
+
+    if (0 == match_quantity) // Try population centers.
+	    match_quantity = pop_locate_place(da, locate_place_name,
+        	locate_state_name, locate_county_name, locate_quad_name,
+        	locate_type_name, locate_gnis_filename,
+		(int)XmToggleButtonGetState(locate_place_case_data),
+       		(int)XmToggleButtonGetState(locate_place_match_data),
+        	match_array_name, match_array_lat, match_array_long);
 
     if (match_quantity) {
         // Found some matches!
