@@ -1,9 +1,9 @@
 /*
- * $Id: main.h,v 1.105 2008/07/03 00:12:04 gstueve Exp $
+ * $Id: main.h,v 1.109 2010/01/31 02:12:24 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2008  The Xastir Group
+ * Copyright (C) 2000-2010  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -237,6 +237,8 @@ typedef struct _what_to_display {
     int phg_of_moving;
 
     int df_data;
+    int df_beamwidth_data;
+    int df_bearing_data;
     int dr_data;
     int dr_arc;
     int dr_course;
@@ -368,7 +370,6 @@ extern void HandlePendingEvents(XtAppContext app);
 extern void create_gc(Widget w);
 extern void Station_info(Widget w, XtPointer clientData, XtPointer calldata);
 extern void Station_List(Widget w, XtPointer clientData, XtPointer calldata);
-extern void Window_Quit(Widget w, XtPointer client, XtPointer call);
 extern void Tracks_All_Clear(Widget w, XtPointer clientData, XtPointer callData);
 extern void Locate_station(Widget w, XtPointer clientData, XtPointer callData);
 extern void Locate_place(Widget w, XtPointer clientData, XtPointer callData);
