@@ -1,9 +1,9 @@
 /* -*- c-basic-offset: 4; indent-tabs-mode: nil -*-
- * $Id: map_geo.c,v 1.94 2008/08/06 03:03:54 gstueve Exp $
+ * $Id: map_geo.c,v 1.107 2010/09/29 03:55:55 jedunmire Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2008  The Xastir Group
+ * Copyright (C) 2000-2010  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -67,6 +67,7 @@
 #include "maps.h"
 #include "map_cache.h"
 #include "alert.h"
+#include "fetch_remote.h"
 #include "util.h"
 #include "main.h"
 #include "datum.h"
@@ -75,6 +76,8 @@
 #include "color.h"
 #include "xa_config.h"
 
+#include "map_OSM.h"
+
 #define CHECKMALLOC(m)  if (!m) { fprintf(stderr, "***** Malloc Failed *****\n"); exit(0); }
 
 
@@ -124,6 +127,14 @@
 #undef PACKAGE_VERSION
 #ifdef HAVE_GRAPHICSMAGICK
 /*#include <GraphicsMagick/magick/api.h>*/
+/* Define MAGICK_IMPLEMENTATION to access private interfaces
+ * such as DestroyImagePixels(). This may not be a good thing,
+ * but DestroyImagePixels() has been in this code for a long
+ * time. Defining MAGIC_IMPLEMENTATION eliminates the warning that is
+ * now (9/28/2010) being seen on some distros (Ubuntu 10.04 and
+ * OpenSuSE-11.3)
+ */
+#define MAGICK_IMPLEMENTATION
 #include <magick/api.h>
 #else   // HAVE_GRAPHICSMAGICK
 #include <magick/api.h>
@@ -552,6 +563,16 @@ void draw_geo_image_map (Widget w,
     FILE *f;                        // Filehandle of image file
     char line[MAX_FILENAME];        // One line from GEO file
     char fileimg[MAX_FILENAME+1];   // Ascii name of image file, read from GEO file
+    char tileCache[MAX_FILENAME+1]; // directory for the OSM tile cache, read from GEO file.
+    char OSMstyle[MAX_OSMSTYLE];
+    char OSMtileExt[MAX_OSMEXT];
+
+    // Start with an empty fileimg[] string so that we can
+    // tell if a URL has been specified in the file. Same for OSMstyle.
+    fileimg[0] = '\0';
+    OSMstyle[0] = '\0';
+    tileCache[0] = '\0';
+    OSMtileExt[0] = '\0';
 
     int width,height;
 #ifndef NO_XPM
@@ -641,6 +662,9 @@ void draw_geo_image_map (Widget w,
     int terraserver_flag = 0;   // U.S. satellite images/topo/reflectivity/urban
                                 // areas via terraserver
     int tigerserver_flag = 0;   // U.S. Street maps via census.gov
+    int OSMserver_flag = 0;     // OpenStreetMaps server, 1 = static maps, 2 = tiled
+    unsigned tmp_zl = 0;
+
     int toporama_flag = 0;      // Canadian topo's from mm.aprs.net (originally from Toporama)
     int WMSserver_flag = 0;     // WMS server
     char map_it[MAX_FILENAME];
@@ -669,7 +693,8 @@ void draw_geo_image_map (Widget w,
     char *cache_file_id;
   #endif  // USE_MAP_CACHE
 #endif  // HAVE_MAGICK
-
+    
+    KeySym OSM_key = 0;
 
     xastir_snprintf(file, sizeof(file), "%s/%s", dir, filenm);
 
@@ -721,7 +746,7 @@ void draw_geo_image_map (Widget w,
                     if (strlen(temp) < (MAX_FILENAME - 1 - strlen(fileimg)))
                         strncat(temp,
                             fileimg,
-                            sizeof(temp) - strlen(temp));
+                            sizeof(temp) - 1 - strlen(temp));
                     xastir_snprintf(fileimg,sizeof(fileimg),"%s",temp);
                 }
             }
@@ -784,6 +809,103 @@ void draw_geo_image_map (Widget w,
             if (strncasecmp (line, "TIGERMAP", 8) == 0)
                 tigerserver_flag = 1;
 
+            if (strncasecmp (line, "OSMSTATICMAP", 12) == 0)
+            {
+                OSMserver_flag = 1;
+                if (strlen(line) > 13) {
+                    if (1 != sscanf (line + 13, "%s", OSMstyle)) {
+                        fprintf(stderr,"draw_geo_image_map:sscanf parsing error for OSM style.\n"); 
+                    }
+                }
+            }
+
+            if (strncasecmp (line, "OSM_TILED_MAP", 13) == 0)
+            {
+                OSMserver_flag = 2;
+                if (strlen(line) > 14) {
+                    if (1 != sscanf (line + 14, "%s", OSMstyle)) {
+                        fprintf(stderr,"draw_geo_image_map:sscanf parsing error for OSM style.\n"); 
+                    }
+                }
+            }
+
+            if (OSMserver_flag > 0) {  // the following keywords are only valid for OSM maps
+                if (strncasecmp (line, "OSM_OPTIMIZE_KEY", 16) == 0){
+                    if ((destination_pixmap != INDEX_CHECK_TIMESTAMPS)
+                            && (destination_pixmap != INDEX_NO_TIMESTAMPS)) {
+                        if (strlen(line) > 17) {
+                            if (1 != sscanf (line + 17, "%lu", &OSM_key)) {
+                                fprintf(stderr,"draw_geo_image_map:sscanf parsing error for OSM_OPTIMIZE_KEY.\n");
+                            } else {
+                                set_OSM_optimize_key(OSM_key);
+                            }
+                        }
+                    }
+                }
+
+                if (strncasecmp (line, "OSM_REPORT_SCALE_KEY", 20) == 0){
+                    if ((destination_pixmap != INDEX_CHECK_TIMESTAMPS)
+                            && (destination_pixmap != INDEX_NO_TIMESTAMPS)) {
+                        if (strlen(line) > 21) {
+                            if (1 != sscanf (line + 21, "%lu", &OSM_key)) {
+                                fprintf(stderr,"draw_geo_image_map:sscanf parsing error for OSM_OPTIMIZE_KEY.\n");
+                            } else {
+                                set_OSM_report_scale_key(OSM_key);
+                            }
+                        }
+                    }
+                }
+
+                if (strncasecmp (line, "TILE_DIR", 8) == 0) {
+                    if (strlen(line) > 9) {
+                        if (1 != sscanf (line + 9, "%s", tileCache)) {
+                        fprintf(stderr,"draw_geo_image_map:sscanf parsing error for TILE_DIR\n");
+                        }
+                    }
+                }
+
+                if (strncasecmp (line, "TILE_EXT", 8) == 0) {
+                    if (strlen(line) > 9) {
+                        if (1 != sscanf (line + 9, "%s", OSMtileExt)) {
+                        fprintf(stderr,"draw_geo_image_map:sscanf parsing error for TILE_EXT\n");
+                        }
+                    }
+                }
+
+                if (strncasecmp(line, "ZOOM_LEVEL_MIN", 14) == 0) {
+                    if (strlen(line) > 15) {
+                        if (1 != sscanf(line + 15, "%u", &tmp_zl)) {
+                            fprintf(stderr, "draw_geo_image_map:sscanf parsing error for ZOOM_LEVEL_MIN\n");
+                        } else {
+                            if (!(osm_zoom_level(scale_x) >= tmp_zl)) {
+                                // skip this map because the zoom level
+                                // is not supported.
+                                if (debug_level & 512) {
+                                    fprintf(stderr, "Skipping OSM map. zl = %u < %u\n", osm_zoom_level(scale_x), tmp_zl);
+                                }
+                                return;
+                            }
+                        }
+                    }
+                }
+                if (strncasecmp(line, "ZOOM_LEVEL_MAX", 14) == 0) {
+                    if (strlen(line) > 15) {
+                        if (1 != sscanf(line + 15, "%u", &tmp_zl)) {
+                            fprintf(stderr, "draw_geo_image_map:sscanf parsing error for ZOOM_LEVEL_MAX\n");
+                        } else {
+                            if (!(tmp_zl >= osm_zoom_level(scale_x))) {
+                                // skip this map because the zoom level
+                                // is not supported.
+                                if (debug_level & 512) {
+                                    fprintf(stderr, "Skipping OSM map. zl = %u > %u\n", osm_zoom_level(scale_x), tmp_zl);
+                                }
+                                return;
+                            }
+                        }
+                    }
+                }
+            }
+
             if (strncasecmp (line, "WMSSERVER", 9) == 0)
                 WMSserver_flag = 1;
 
@@ -956,6 +1078,36 @@ void draw_geo_image_map (Widget w,
 
         return;
     }
+    //
+    // Check whether OpenStreetMap has been selected.  If so, run off to
+    // another routine to service this request.
+    //
+    if (OSMserver_flag == 1) {
+
+#ifdef HAVE_MAGICK
+
+        // We need to send the "nocache" parameter to this function
+        // for those instances when the received map is bad.
+        // Later the GUI can implement a method for refreshing the
+        // latest map and replacing the bad map in the cache.
+        //
+        // fileimg is the server URL, if specified.
+        draw_OSM_map(w, filenm, destination_pixmap, fileimg, OSMstyle, nocache);
+
+#endif  // HAVE_MAGICK
+
+        return;
+    } else if (OSMserver_flag == 2) {
+#ifdef HAVE_MAGICK
+
+        // fileimg is the server URL, if specified.
+        draw_OSM_tiles(w, filenm, destination_pixmap, fileimg, tileCache, OSMstyle, OSMtileExt);
+
+#endif  // HAVE_MAGICK
+
+        return;
+    }
+
 
 
     // Check whether a WMS server has been selected.  If so, run off
@@ -1859,10 +2011,10 @@ fprintf(stderr,"2 ");
     //         lower loops to speed them up... 
     if ( do_crop) {
         int x, y;
-        PixelPacket target;
+        //        PixelPacket target;
         register PixelPacket *q;
-        
-        target=GetOnePixel(image,0,0);
+      
+        //        target=GetOnePixel(image,0,0);
         for (y=0; y < (long) image->rows; y++) {
             q=GetImagePixels(image,0,y,image->columns,1);
             if (q == (PixelPacket *) NULL)
@@ -2328,9 +2480,26 @@ fprintf(stderr,"2 ");
                                 trans_skip = 0; // draw it
                             }
                         } else {
-                            pack_pixel_bits(pixel_pack[l].red * raster_map_intensity,
-                                            pixel_pack[l].green * raster_map_intensity,
-                                            pixel_pack[l].blue * raster_map_intensity,
+                            // It is not safe to assume that the red/green/blue
+                            // elements of pixel_pack of type Quantum are the
+                            // same as the red/green/blue of an XColor!
+                            if (QuantumDepth==16) {
+                                my_colors[0].red=pixel_pack[l].red;
+                                my_colors[0].green=pixel_pack[l].green;
+                                my_colors[0].blue=pixel_pack[l].blue;
+                            }
+                            else { // QuantumDepth=8
+                                // shift the bits of the 8-bit quantity so that
+                                // they become the high bigs of my_colors.*
+                                my_colors[0].red=pixel_pack[l].red<<8;
+                                my_colors[0].green=pixel_pack[l].green<<8;
+                                my_colors[0].blue=pixel_pack[l].blue<<8;
+                            }
+                            // NOW my_colors has the right r,g,b range for
+                            // pack_pixel_bits
+                            pack_pixel_bits(my_colors[0].red * raster_map_intensity,
+                                            my_colors[0].green * raster_map_intensity,
+                                            my_colors[0].blue * raster_map_intensity,
                                             &my_colors[0].pixel);
                             if ( trans_color_head && 
                                     check_trans(my_colors[0],trans_color_head) ) {
