@@ -1,9 +1,9 @@
 /* -*- c-basic-offset: 4; indent-tabs-mode: nil -*-
- * $Id: map_tiger.c,v 1.59 2008/08/01 12:42:59 gstueve Exp $
+ * $Id: map_tiger.c,v 1.66 2010/07/27 08:40:20 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2008  The Xastir Group
+ * Copyright (C) 2000-2010  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -65,6 +65,7 @@
 #include "xastir.h"
 #include "maps.h"
 #include "alert.h"
+#include "fetch_remote.h"
 #include "util.h"
 #include "main.h"
 #include "datum.h"
@@ -415,81 +416,81 @@ void draw_tiger_map (Widget w,
     xastir_snprintf(tigertmp, sizeof(tigertmp), "http://tiger.census.gov/cgi-bin/mapper/map.gif?");
 
     if (tiger_show_grid)
-        strncat(tigertmp, "&on=GRID", sizeof(tigertmp) - strlen(tigertmp));
+        strncat(tigertmp, "&on=GRID", sizeof(tigertmp) - 1 - strlen(tigertmp));
     else
-        strncat(tigertmp, "&off=GRID", sizeof(tigertmp) - strlen(tigertmp));
+        strncat(tigertmp, "&off=GRID", sizeof(tigertmp) - 1 - strlen(tigertmp));
 
     if (tiger_show_counties)
-        strncat(tigertmp, "&on=counties", sizeof(tigertmp) - strlen(tigertmp));
+        strncat(tigertmp, "&on=counties", sizeof(tigertmp) - 1 - strlen(tigertmp));
     else
-        strncat(tigertmp, "&off=counties", sizeof(tigertmp) - strlen(tigertmp));
+        strncat(tigertmp, "&off=counties", sizeof(tigertmp) - 1 - strlen(tigertmp));
 
     if (tiger_show_cities)
-        strncat(tigertmp, "&on=CITIES", sizeof(tigertmp) - strlen(tigertmp));
+        strncat(tigertmp, "&on=CITIES", sizeof(tigertmp) - 1 - strlen(tigertmp));
     else
-        strncat(tigertmp, "&off=CITIES", sizeof(tigertmp) - strlen(tigertmp));
+        strncat(tigertmp, "&off=CITIES", sizeof(tigertmp) - 1 - strlen(tigertmp));
 
     if (tiger_show_places)
-        strncat(tigertmp, "&on=places", sizeof(tigertmp) - strlen(tigertmp));
+        strncat(tigertmp, "&on=places", sizeof(tigertmp) - 1 - strlen(tigertmp));
     else
-        strncat(tigertmp, "&off=places", sizeof(tigertmp) - strlen(tigertmp));
+        strncat(tigertmp, "&off=places", sizeof(tigertmp) - 1 - strlen(tigertmp));
 
     if (tiger_show_majroads)
-        strncat(tigertmp, "&on=majroads", sizeof(tigertmp) - strlen(tigertmp));
+        strncat(tigertmp, "&on=majroads", sizeof(tigertmp) - 1 - strlen(tigertmp));
     else
-        strncat(tigertmp, "&off=majroads", sizeof(tigertmp) - strlen(tigertmp));
+        strncat(tigertmp, "&off=majroads", sizeof(tigertmp) - 1 - strlen(tigertmp));
 
     if (tiger_show_streets)
-        strncat(tigertmp, "&on=streets", sizeof(tigertmp) - strlen(tigertmp));
+        strncat(tigertmp, "&on=streets", sizeof(tigertmp) - 1 - strlen(tigertmp));
     // Don't turn streets off since this will automagically show up as you zoom in.
 
     if (tiger_show_railroad)
-        strncat(tigertmp, "&on=railroad", sizeof(tigertmp) - strlen(tigertmp));
+        strncat(tigertmp, "&on=railroad", sizeof(tigertmp) - 1 - strlen(tigertmp));
     else
-        strncat(tigertmp, "&off=railroad", sizeof(tigertmp) - strlen(tigertmp));
+        strncat(tigertmp, "&off=railroad", sizeof(tigertmp) - 1 - strlen(tigertmp));
 
     if (tiger_show_states)
-        strncat(tigertmp, "&on=states", sizeof(tigertmp) - strlen(tigertmp));
+        strncat(tigertmp, "&on=states", sizeof(tigertmp) - 1 - strlen(tigertmp));
     else
-        strncat(tigertmp, "&off=states", sizeof(tigertmp) - strlen(tigertmp));
+        strncat(tigertmp, "&off=states", sizeof(tigertmp) - 1 - strlen(tigertmp));
 
     if (tiger_show_interstate)
-        strncat(tigertmp, "&on=interstate", sizeof(tigertmp) - strlen(tigertmp));
+        strncat(tigertmp, "&on=interstate", sizeof(tigertmp) - 1 - strlen(tigertmp));
     else
-        strncat(tigertmp, "&off=interstate", sizeof(tigertmp) - strlen(tigertmp));
+        strncat(tigertmp, "&off=interstate", sizeof(tigertmp) - 1 - strlen(tigertmp));
 
     if (tiger_show_ushwy)
-        strncat(tigertmp, "&on=ushwy", sizeof(tigertmp) - strlen(tigertmp));
+        strncat(tigertmp, "&on=ushwy", sizeof(tigertmp) - 1 - strlen(tigertmp));
     else
-        strncat(tigertmp, "&off=ushwy", sizeof(tigertmp) - strlen(tigertmp));
+        strncat(tigertmp, "&off=ushwy", sizeof(tigertmp) - 1 - strlen(tigertmp));
 
     if (tiger_show_statehwy)
-        strncat(tigertmp, "&on=statehwy", sizeof(tigertmp) - strlen(tigertmp));
+        strncat(tigertmp, "&on=statehwy", sizeof(tigertmp) - 1 - strlen(tigertmp));
     else
-        strncat(tigertmp, "&off=statehwy", sizeof(tigertmp) - strlen(tigertmp));
+        strncat(tigertmp, "&off=statehwy", sizeof(tigertmp) - 1 - strlen(tigertmp));
 
     if (tiger_show_water)
-        strncat(tigertmp, "&on=water", sizeof(tigertmp) - strlen(tigertmp));
+        strncat(tigertmp, "&on=water", sizeof(tigertmp) - 1 - strlen(tigertmp));
     else
-        strncat(tigertmp, "&off=water", sizeof(tigertmp) - strlen(tigertmp));
+        strncat(tigertmp, "&off=water", sizeof(tigertmp) - 1 - strlen(tigertmp));
 
     if (tiger_show_lakes)
-        strncat(tigertmp, "&on=shorelin", sizeof(tigertmp) - strlen(tigertmp));
+        strncat(tigertmp, "&on=shorelin", sizeof(tigertmp) - 1 - strlen(tigertmp));
     else
-        strncat(tigertmp, "&off=shorelin", sizeof(tigertmp) - strlen(tigertmp));
+        strncat(tigertmp, "&off=shorelin", sizeof(tigertmp) - 1 - strlen(tigertmp));
 
     if (tiger_show_misc)
-        strncat(tigertmp, "&on=miscell", sizeof(tigertmp) - strlen(tigertmp));
+        strncat(tigertmp, "&on=miscell", sizeof(tigertmp) - 1 - strlen(tigertmp));
     else
-        strncat(tigertmp, "&off=miscell", sizeof(tigertmp) - strlen(tigertmp));
+        strncat(tigertmp, "&off=miscell", sizeof(tigertmp) - 1 - strlen(tigertmp));
 
     xastir_snprintf(tmpstr, sizeof(tmpstr), "&lat=%f\046lon=%f\046", lat_center, long_center);    
-    strncat (tigertmp, tmpstr, sizeof(tigertmp) - strlen(tigertmp));
+    strncat (tigertmp, tmpstr, sizeof(tigertmp) - 1 - strlen(tigertmp));
     xastir_snprintf(tmpstr, sizeof(tmpstr), "wid=%f\046ht=%f\046", map_width, map_height);
-    strncat (tigertmp, tmpstr, sizeof(tigertmp) - strlen(tigertmp));
+    strncat (tigertmp, tmpstr, sizeof(tigertmp) - 1 - strlen(tigertmp));
     xastir_snprintf(tmpstr, sizeof(tmpstr), "iwd=%i\046iht=%i", tp[1].img_x + 1, tp[1].img_y + 1);
-    strncat (tigertmp, tmpstr, sizeof(tigertmp) - strlen(tigertmp));
-    xastir_snprintf(fileimg, sizeof(fileimg), tigertmp);
+    strncat (tigertmp, tmpstr, sizeof(tigertmp) - 1 - strlen(tigertmp));
+    xastir_snprintf(fileimg, sizeof(fileimg), "%s", tigertmp);
 
     if (debug_level & 512) {
           fprintf(stderr,"left side is %f\n", left);
@@ -898,6 +899,7 @@ void draw_tiger_map (Widget w,
                 (unsigned int)screen_height,
                 0,
                 0);
+            DestroyExceptionInfo(&exception);
             return;
         }
 
@@ -924,9 +926,26 @@ void draw_tiger_map (Widget w,
                             XSetForeground(XtDisplay(w), gc, my_colors[index_pack[l]].pixel);
                         }
                         else {
-                            pack_pixel_bits(pixel_pack[l].red * raster_map_intensity,
-                                            pixel_pack[l].green * raster_map_intensity,
-                                            pixel_pack[l].blue * raster_map_intensity,
+                            // It is not safe to assume that the red/green/blue
+                            // elements of pixel_pack of type Quantum are the
+                            // same as the red/green/blue of an XColor!
+                            if (QuantumDepth==16) {
+                                my_colors[0].red=pixel_pack[l].red;
+                                my_colors[0].green=pixel_pack[l].green;
+                                my_colors[0].blue=pixel_pack[l].blue;
+                            }
+                            else { // QuantumDepth=8
+                                // shift the bits of the 8-bit quantity so that
+                                // they become the high bigs of my_colors.*
+                                my_colors[0].red=pixel_pack[l].red<<8;
+                                my_colors[0].green=pixel_pack[l].green<<8;
+                                my_colors[0].blue=pixel_pack[l].blue<<8;
+                            }
+                            // NOW my_colors has the right r,g,b range for
+                            // pack_pixel_bits
+                            pack_pixel_bits(my_colors[0].red * raster_map_intensity,
+                                            my_colors[0].green * raster_map_intensity,
+                                            my_colors[0].blue * raster_map_intensity,
                                             &my_colors[0].pixel);
                             XSetForeground(XtDisplay(w), gc, my_colors[0].pixel);
                         }
