@@ -1,9 +1,9 @@
 /*
- * $Id: messages.h,v 1.27 2008/01/16 19:34:02 we7u Exp $
+ * $Id: messages.h,v 1.30 2010/01/31 02:12:24 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2008  The Xastir Group
+ * Copyright (C) 2000-2010  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -116,6 +116,8 @@ extern void Send_message_call(Widget w, XtPointer clientData, XtPointer callData
 // view_message_gui.c
 extern int vm_range;
 extern int view_message_limit;
+extern int Read_messages_packet_data_type;
+extern int Read_messages_mine_only;
 
 #endif  /*  XASTIR_MESSAGES_H */
 
