@@ -1,9 +1,9 @@
 /*
- * $Id: messages_gui.c,v 1.81 2008/07/02 03:04:43 we7u Exp $
+ * $Id: messages_gui.c,v 1.85 2010/07/11 23:31:40 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2008  The Xastir Group
+ * Copyright (C) 2000-2010  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -30,6 +30,7 @@
 
 #include <stdlib.h>
 #include <stdio.h>                      // printf
+#include <stdint.h>
 
 #include <Xm/XmAll.h>
 
@@ -237,7 +238,7 @@ void get_path_data(char *callsign, char *path, int max_length) {
         char new_path[200];
 
         if (p_station->node_path_ptr) {
-            xastir_snprintf(new_path,sizeof(new_path),p_station->node_path_ptr);
+            xastir_snprintf(new_path,sizeof(new_path), "%s", p_station->node_path_ptr);
             
             if(debug_level & 2)
                 fprintf(stderr,"\nPath from %s: %s\n",
@@ -904,10 +905,10 @@ end_critical_section(&send_message_dialog_lock, "messages_gui.c:Send_message_des
 
 
 void Check_new_call_messages( /*@unused@*/ Widget w, XtPointer clientData, /*@unused@*/ XtPointer callData) {
-    int i, pos;
+    int pos;
+    intptr_t i;
 
-
-    i=(int)clientData;
+    i=(intptr_t)clientData;
  
     /* clear window*/
     pos=0;
@@ -1733,7 +1734,7 @@ void rebuild_send_message_input_boxes(int ii, int hamhud, int d700, int d7) {
 
 
 void HamHUD_Msg( /*@unused@*/ Widget widget, XtPointer clientData, XtPointer callData) {
-    int ii = (int)clientData;
+    intptr_t ii =(intptr_t)clientData;
     int hamhud;
 
     hamhud = XmToggleButtonGetState(mw[ii].HamHUD_mode);
@@ -1750,7 +1751,7 @@ void HamHUD_Msg( /*@unused@*/ Widget widget, XtPointer clientData, XtPointer cal
 
 
 void D700_Msg( /*@unused@*/ Widget widget, XtPointer clientData, XtPointer callData) {
-    int ii = (int)clientData;
+    intptr_t ii = (intptr_t)clientData;
     int d700;
 
     d700 = XmToggleButtonGetState(mw[ii].D700_mode);
@@ -1767,7 +1768,7 @@ void D700_Msg( /*@unused@*/ Widget widget, XtPointer clientData, XtPointer callD
 
 
 void D7_Msg( /*@unused@*/ Widget widget, XtPointer clientData, XtPointer callData) {
-    int ii = (int)clientData;
+    intptr_t ii = (intptr_t)clientData;
     int d7;
 
     d7 = XmToggleButtonGetState(mw[ii].D7_mode);
@@ -1938,7 +1939,8 @@ void Send_message( /*@unused@*/ Widget w, XtPointer clientData, /*@unused@*/ XtP
     Arg args[50];
     char temp[60];
     unsigned int n;
-    int j,i;
+    int j;
+    intptr_t i;
     char group[MAX_CALLSIGN+1];
     int groupon;
     int box_len;
@@ -2260,7 +2262,7 @@ begin_critical_section(&send_message_dialog_lock, "messages_gui.c:Send_message"
                 XmNfontList, fontlist1,
                 NULL);
 
-        xastir_snprintf(temp, sizeof(temp), langcode(groupon == 0 ? "WPUPMSB005": "WPUPMSB006"));
+        xastir_snprintf(temp, sizeof(temp), "%s", langcode(groupon == 0 ? "WPUPMSB005": "WPUPMSB006"));
 
         mw[i].button_submit_call = XtVaCreateManagedWidget(temp,
                 xmPushButtonGadgetClass, 
@@ -2374,7 +2376,7 @@ begin_critical_section(&send_message_dialog_lock, "messages_gui.c:Send_message"
                 args,
                 n);
 
-        xastir_snprintf(mw[i].win, sizeof(mw[i].win), "%d", i);
+        xastir_snprintf(mw[i].win, sizeof(mw[i].win), "%ld", i);
 
         XtAddCallback(mw[i].send_message_change_path, XmNactivateCallback, Send_message_change_path, (XtPointer)mw[i].win);
  
@@ -2443,7 +2445,7 @@ end_critical_section(&send_message_dialog_lock, "messages_gui.c:Send_message" );
 // outbound messages.
 //
 void Show_pending_messages( /*@unused@*/ Widget w, /*@unused@*/ XtPointer clientData, /*@unused@*/ XtPointer callData) {
-    int ii;
+    intptr_t ii;
     int msgs_found = 0;
 
 
