@@ -1,9 +1,9 @@
 /*
- * $Id: objects.h,v 1.10 2008/01/16 19:34:02 we7u Exp $
+ * $Id: objects.h,v 1.13 2010/07/11 23:39:42 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2008  The Xastir Group
+ * Copyright (C) 2000-2010  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -26,6 +26,7 @@
 #define XASTIR_OBJECTS_H
 
 #include <X11/Intrinsic.h>
+#include <stdint.h>
 
 
 // For mutex debugging with Linux threads only
@@ -116,7 +117,7 @@ typedef struct {
     char data[PREDEFINED_OBJECT_DATA_LENGTH]; 
                                 // Data following the symbol.
     char menu_call[26];         // Name to display on menu.
-    int index;                  // Index of this object 
+    intptr_t index;             // Index of this object 
                                 // in the predefinedObjects array.
     int show_on_menu;           // !=1 to hide on menu.
     int index_of_child;         // > -1 to create two objects
