@@ -1,9 +1,9 @@
 /* -*- c-basic-offset: 4; indent-tabs-mode: nil -*-
- * $Id: index.h,v 1.8 2008/01/16 19:34:03 we7u Exp $
+ * $Id: index.h,v 1.11 2010/07/11 21:41:11 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2008  The Xastir Group
+ * Copyright (C) 2000-2010  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -95,12 +95,12 @@ struct ListNode
  * It can terminate the search early by returning 0 in which case
  * the search will return the number of hits found up to that point.
  */
-typedef int (*SearchHitCallback)(int id, void* arg);
+typedef int (*SearchHitCallback)(void *id, void* arg);
 
 
 extern int Xastir_RTreeSearch(struct Node*, struct Rect*, SearchHitCallback, void*);
-extern int Xastir_RTreeInsertRect(struct Rect*, int, struct Node**, int depth);
-extern int Xastir_RTreeDeleteRect(struct Rect*, int, struct Node**);
+extern int Xastir_RTreeInsertRect(struct Rect*, void *, struct Node**, int depth);
+extern int Xastir_RTreeDeleteRect(struct Rect*, void *, struct Node**);
 extern struct Node * Xastir_RTreeNewIndex(void);
 extern struct Node * Xastir_RTreeNewNode(void);
 extern void Xastir_RTreeInitNode(struct Node*);
