@@ -1,9 +1,9 @@
 /* -*- c-basic-offset: 4; indent-tabs-mode: nil -*-
- * $Id: shp_hash.c,v 1.20 2008/01/16 19:34:02 we7u Exp $
+ * $Id: shp_hash.c,v 1.28 2010/07/11 23:31:40 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2008  The Xastir Group
+ * Copyright (C) 2000-2010  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -31,6 +31,7 @@
 
 #include <stdlib.h>
 #include <stdio.h>
+#include <stdint.h>
 
 #if TIME_WITH_SYS_TIME
 # include <sys/time.h>
@@ -63,6 +64,7 @@
 /// THIS ONLY FOR DEBUGGING!
 #include "hashtable_private.h"
 #include "shp_hash.h"
+#include "snprintf.h"
 
 // Must be last include file
 #include "leak_detection.h"
@@ -234,8 +236,11 @@ void add_shp_to_hash(char *filename, SHPHandle sHP) {
     // leave room for terminator
     temp->filename = (char *) malloc(sizeof(char)*(filenm_len+1));
     CHECKMALLOC(temp->filename);
+
     strncpy(temp->filename,filename,filenm_len+1);
     temp->filename[filenm_len]='\0';  // just to be safe
+//    xastir_snprintf(temp->filename,sizeof(shpinfo),"%s",filename);
+
     temp->root = Xastir_RTreeNewIndex();  
     temp->creation = sec_now();
     temp->last_access = temp->creation;
@@ -289,24 +294,28 @@ shpinfo *get_shp_from_hash(char *filename) {
 // Must not ever use cache a value of the root pointer if there's any
 // chance that the tree needs to be expanded!
 void build_rtree (struct Node **root, SHPHandle sHP) {
-    int nEntities,i;
+    int nEntities;
+    intptr_t i;
     SHPObject	*psCShape;
     struct Rect bbox_shape;
     SHPGetInfo(sHP, &nEntities, NULL, NULL, NULL);
     for( i = 0; i < nEntities; i++ ) {
         psCShape = SHPReadObject ( sHP, i );
-        bbox_shape.boundary[0]=(RectReal) psCShape->dfXMin;
-        bbox_shape.boundary[1]=(RectReal) psCShape->dfYMin;
-        bbox_shape.boundary[2]=(RectReal) psCShape->dfXMax;
-        bbox_shape.boundary[3]=(RectReal) psCShape->dfYMax;
-        SHPDestroyObject ( psCShape );
-        // Only insert the rect if it will not fail the assertion in 
-        // Xastir_RTreeInsertRect --- this will cause us to ignore any shapes that
-        // have invalid bboxes (or that return invalid bboxes from shapelib
-        // for whatever reason
-        if (bbox_shape.boundary[0] <= bbox_shape.boundary[2] &&
-            bbox_shape.boundary[1] <= bbox_shape.boundary[3])
-            Xastir_RTreeInsertRect(&bbox_shape,i+1,root,0);
+     	if (psCShape != NULL) {
+            bbox_shape.boundary[0]=(RectReal) psCShape->dfXMin;
+            bbox_shape.boundary[1]=(RectReal) psCShape->dfYMin;
+            bbox_shape.boundary[2]=(RectReal) psCShape->dfXMax;
+            bbox_shape.boundary[3]=(RectReal) psCShape->dfYMax;
+            SHPDestroyObject ( psCShape );
+            // Only insert the rect if it will not fail the assertion in 
+            // Xastir_RTreeInsertRect --- this will cause us to ignore any shapes that
+            // have invalid bboxes (or that return invalid bboxes from shapelib
+            // for whatever reason
+            if (bbox_shape.boundary[0] <= bbox_shape.boundary[2] &&
+                    bbox_shape.boundary[1] <= bbox_shape.boundary[3]) {
+                Xastir_RTreeInsertRect(&bbox_shape, (void *)(i+1), root, 0);
+            }
+        }
     }
 }
 
@@ -314,16 +323,12 @@ void build_rtree (struct Node **root, SHPHandle sHP) {
 
 
 
-void purge_shp_hash(void) {
+void purge_shp_hash(time_t secs_now) {
     struct hashtable_itr *iterator=NULL;
     shpinfo *si;
-    time_t secs_now;
-    //struct tm *time_now;
     int ret;
-    //    char timestring[256];
 
 
-    secs_now = sec_now();
     if (secs_now > purge_time) {  // Time to purge
         //time_now = localtime(&secs_now);
         //(void)strftime(timestring,100,"%a %b %d %H:%M:%S %Z %Y",time_now);
