@@ -1,9 +1,9 @@
 /*
- * $Id: track_gui.c,v 1.71 2008/07/02 03:04:44 we7u Exp $
+ * $Id: track_gui.c,v 1.75 2010/07/27 08:40:20 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2008  The Xastir Group
+ * Copyright (C) 2000-2010  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -40,6 +40,7 @@
 #include "lang.h"
 #include "objects.h"
 #include "popup.h"
+#include "fetch_remote.h"
 #include "util.h"
 #include "xa_config.h"
 
@@ -482,6 +483,7 @@ static void* findu_transfer_thread(void *arg) {
     // Set permissions on the file so that any user can overwrite it.
     chmod(log_filename, 0666);
 
+#if defined(HAVE_SED)
     // Add three spaces before each "<br>" and axe the "<br>".  This
     // is so that Base-91 compressed packets with no comment and no
     // speed/course/altitude will get decoded ok.  Otherwise the
@@ -553,7 +555,7 @@ static void* findu_transfer_thread(void *arg) {
         SED_PATH,
         log_filename);
     system(sys_cmd);
-
+#endif  // HAVE_SED
 
 /*
 #ifdef HAVE_HTML2TEXT
@@ -572,12 +574,14 @@ static void* findu_transfer_thread(void *arg) {
     // Rename the file so that we can keep the static char* name
     // pointing to it, needed for the read_file_ptr code in the main
     // thread.
+#if defined(HAVE_MV)
     sprintf(sys_cmd,
         "%s %s %s",
         MV_PATH,
         log_filename_tmp,
         log_filename);
     system(sys_cmd);
+#endif  // HAVE_MV
 #endif  // HAVE_HTML2TEXT
 */
 
