@@ -1,9 +1,9 @@
 /*
- * $Id: util.h,v 1.57 2008/07/28 08:37:36 we7u Exp $
+ * $Id: util.h,v 1.61 2010/08/10 08:22:53 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2008  The Xastir Group
+ * Copyright (C) 2000-2010  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -162,10 +162,7 @@ extern char *sec_to_loc(long longitude, long latitude);
 
 extern short checkHash(char *theCall, short theHash);
 
-int fetch_remote_file(char *fileimg, char *local_filename);
-
-extern void split_string( char *data, char *cptr[], int max );
-extern void split_string_char ( char *data, char *cptr[], int max, char search_char );
+extern void split_string ( char *data, char *cptr[], int max, char search_char );
 extern int check_unproto_path( char *data );
 
 extern void set_dangerous( char *ptr );
