@@ -1,9 +1,9 @@
 /*
- * $Id: view_message_gui.c,v 1.38 2008/07/02 03:04:44 we7u Exp $
+ * $Id: view_message_gui.c,v 1.42 2010/06/09 23:28:56 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2008  The Xastir Group
+ * Copyright (C) 2000-2010  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -75,7 +75,7 @@ static xastir_mutex All_messages_dialog_lock;
 
 int vm_range;
 int view_message_limit = 10000;
-int Read_messages_packet_data_type = 0;
+int Read_messages_packet_data_type = 0; // 1=tnc_only, 2=net_only, 0=tnc&net
 int Read_messages_mine_only = 0;
 
 
@@ -293,7 +293,7 @@ void all_messages(char from, char *call_sign, char *from_call, char *message) {
         if (strncmp(call_sign, "java",4) == 0) {
             xastir_snprintf(call_sign,
                 MAX_CALLSIGN+1,
-                langcode("WPUPMSB015") );   // Broadcast
+                "%s", langcode("WPUPMSB015") );   // Broadcast
             xastir_snprintf(temp,
                 my_size,
                 "%s %s\t%s%s\n",
@@ -304,7 +304,7 @@ void all_messages(char from, char *call_sign, char *from_call, char *message) {
         } else if (strncmp(call_sign, "USER", 4) == 0) {
             xastir_snprintf(call_sign,
                 MAX_CALLSIGN+1,
-                langcode("WPUPMSB015") );   // Broadcast
+                "%s", langcode("WPUPMSB015") );   // Broadcast
             xastir_snprintf(temp,
                 my_size,
                 "%s %s\t%s%s\n",
@@ -630,7 +630,7 @@ begin_critical_section(&All_messages_dialog_lock, "view_message_gui.c:view_all_m
                 NULL);
  
         XtAddCallback(read_mine_only_button,XmNvalueChangedCallback,Read_messages_mine_only_toggle,"1");
- 
+
         n=0;
         XtSetArg(args[n], XmNrows, 15); IncN(n);
         XtSetArg(args[n], XmNcolumns, 85); IncN(n);
@@ -729,3 +729,4 @@ end_critical_section(&All_messages_dialog_lock, "view_message_gui.c:view_all_mes
     }
 }
 
+
