@@ -1,9 +1,9 @@
 /*
- * $Id: wx_gui.c,v 1.55 2008/07/02 03:04:44 we7u Exp $
+ * $Id: wx_gui.c,v 1.59 2010/06/09 23:28:56 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2008  The Xastir Group
+ * Copyright (C) 2000-2010  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -261,7 +261,14 @@ end_critical_section(&wx_detailed_alert_shell_lock, "wx_gui.c:wx_alert_double_cl
 
     memset(&serv_addr, 0, sizeof(serv_addr));
 
-    serverhost = gethostbyname("wxsvr.net");
+
+    // Changing Finger host because WXSVR.net has been down for a
+    // month or more and Pete, AE5PL, has a replacement online that
+    // performs this function.
+    //serverhost = gethostbyname("wxsvr.net");
+    serverhost = gethostbyname("wx.aprs-is.net");
+
+
     if (serverhost == (struct hostent *)0) {
 //        fprintf(stderr,"wx_alert_finger_output: gethostbyname failed\n");
         xastir_snprintf(temp,
@@ -311,7 +318,7 @@ end_critical_section(&wx_detailed_alert_shell_lock, "wx_gui.c:wx_alert_double_cl
         handle);
 
     // Send the request text out the socket
-    ret = fprintf(fd, temp);
+    ret = fprintf(fd, "%s", temp);
 
     if (ret == 0 || ret == -1) {
 //        fprintf(stderr,"Couldn't send finger command to wxsvr\n");
