@@ -1,8 +1,8 @@
 /*
- * $Id: x_spider.c,v 1.59 2008/06/11 13:39:24 gstueve Exp $
+ * $Id: x_spider.c,v 1.66 2010/08/10 08:22:53 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
- * Copyright (C) 2003-2008  The Xastir Group
+ * Copyright (C) 2003-2010  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -185,7 +185,8 @@
 // because it causes other problems.
 extern short checkHash(char *theCall, short theHash);
 extern void get_timestamp(char *timestring);
-extern void split_string( char *data, char *cptr[], int max );
+extern void split_string( char *data, char *cptr[], int max, char search_char );
+
 
 // From database.h
 extern char my_callsign[];
@@ -196,6 +197,7 @@ typedef struct _pipe_object {
     int to_parent[2];
     char callsign[20];
     int authenticated;
+    int active;		// Mark for deletion after every task is finished
     struct _pipe_object *next;
 } pipe_object;
 
@@ -505,10 +507,9 @@ int pipe_check(char *client_address) {
         // Read data from pipe, write to all pipes except the one
         // who sent it.
         //
-        n = readline(p->to_parent[0], line, MAXLINE);
-        if (n == 0) {
+        n = p->active ? readline(p->to_parent[0], line, MAXLINE): 0;
+        if (n == 0 && p->active) {
             char timestring[101];
-            pipe_object *q = pipe_head;
 
             get_timestamp(timestring);
 
@@ -530,18 +531,7 @@ int pipe_check(char *client_address) {
             close(p->to_child[1]);
             close(p->to_parent[0]);
 
-            // Unlink this record from our list
-            if (q == p) {   // Beginning of list?
-                pipe_head = q->next;
-            }
-            else {
-                while (q->next != p && q != NULL)
-                    q = q->next;    
-                if (q != NULL)
-                    q->next = p->next;
-            }
-            free(p);    // Free the malloc'd memory.
-	    p = NULL;
+            p->active = 0;	// This task is ready to let go.
 
             wait(NULL); // Reap the status of the dead process
         }
@@ -555,7 +545,7 @@ int pipe_check(char *client_address) {
                 fprintf(stderr,"pipe_check: Readline error: %d\n",errno);
             }
         }
-        else {  // We received some data.  Send it down all of the
+        else if (p->active) {  // We received some data.  Send it down all of the
                 // pipes except the one that sent it.
 
             pipe_object *q;
@@ -587,7 +577,7 @@ int pipe_check(char *client_address) {
                 // Add white space to the end.
                 strncat(line2,
                     "                                    ",
-                    sizeof(line2) - strlen(line2));
+                    sizeof(line2) - 1 - strlen(line2));
 
                 // Find the "user" string position
                 callsign = strstr(line2,"user");
@@ -681,7 +671,8 @@ int pipe_check(char *client_address) {
             while (q != NULL) {
 //                fprintf(stderr,"pipe_check: %s\n",line);
 
-                if (q != p) {
+                // Only send to active pipes
+                if (q != p && q->active) {
                     if (writen(q->to_child[1], line, n) != n) {
                         fprintf(stderr,"pipe_check: Writen error1: %d\n",errno);
                     }
@@ -722,7 +713,7 @@ int pipe_check(char *client_address) {
             }
         }
 
-        p = p->next;
+        if (p) p = p->next;
     }
 
 
@@ -748,13 +739,46 @@ int pipe_check(char *client_address) {
     else {  // We received some data.  Send it down all of the
             // pipes.
 // Also send it down the socket.
+
+        // Check for disconnected clients and delete their records
+        // from the chain.
         pipe_object *q = pipe_head;
+        pipe_object *r = pipe_head;
+        for (q = pipe_head; q != NULL; ) {
 
+            if (!q->active) { // Marked for deletion.
 
-//fprintf(stderr,"n:%d\n",n);
-// Terminate it
-line[n] = '\0';
-//fprintf(stderr,"sp %s\n", line);
+                // Check for head of list, handle it in a special
+                // manner.  We don't have to fix up the "next"
+                // pointer on the previous object (it doesn't exist)
+                // but must fix up "pipe_head" pointer.
+                if (q == pipe_head) {
+                    pipe_head = q->next;  // New head of list
+                    p = q; // Assign temporary pointer
+                    q = q->next; // Keep pointer to next object
+                    r = q;  // Keep 'r' and 'q' the same for now,
+                            // later 'r' will lag 'q' by one object
+                    free(p); // Free struct at temporary pointer
+                }
+                else { // Not the head object
+                    r->next = q->next; // Bridge soon-to-be-made gap
+                    p = q; // Assign temporary pointer
+                    q = q->next; // Keep pointer to next connection.
+                    free(p); // Free struct at temp pointer
+                }
+            }
+            else {
+                r = q;  // Pointer to last object (so we can get to
+                        // the "next" pointer)
+                q = q->next; // Pointer to next object
+            }
+        }
+        q = pipe_head; // Reset pointer to beginning of list
+
+        //fprintf(stderr,"n:%d\n",n);
+        // Terminate it
+        line[n] = '\0';
+        //fprintf(stderr,"sp %s\n", line);
  
         // The internet protocol for sending lines is "\r\n".  Knock
         // off any line-end characters that might be present, then
@@ -772,7 +796,7 @@ line[n] = '\0';
         strncat(line, "\r\n", 2);
         n += 2;
 
-        while (q != NULL) {
+        while (q != NULL && q->active) {
 //          fprintf(stderr,"pipe_check: %s\n",line);
 
             if (writen(q->to_child[1], line, n) != n) {
@@ -808,10 +832,31 @@ extern char *__progname, *__progname_full;
 #endif  // __LSB__
 #endif  // __linux__
 static char *LastArgv = ((void *)0);
-extern char **environ;
+static char **local_environ;
+static char *old_progname, *old_progname_full;
 
 
 
+void clear_proc_title(void)
+{
+  int i;
+  for(i = 0; local_environ && local_environ[i] != NULL; i++) {
+    free(local_environ[i]);
+  }
+  if (local_environ) {
+    free(local_environ);
+    local_environ = NULL;
+  }
+#ifdef __linux__
+#ifndef __LSB__
+  free(__progname);
+  free(__progname_full);
+  __progname = old_progname;
+  __progname_full = old_progname_full;
+#endif  // __LSB__
+#endif  // __linux__
+}
+
 void init_set_proc_title(int argc, char *argv[], char *envp[]) {
     int i, envpsize;
     char **p;
@@ -820,45 +865,37 @@ void init_set_proc_title(int argc, char *argv[], char *envp[]) {
         envpsize += strlen(envp[i]) + 1;
   
     if((p = (char **) malloc((i + 1) * sizeof(char *))) != NULL ) {
-        environ = p;
+        local_environ = p;
 
     for(i = 0; envp[i] != NULL; i++) {
-        if((environ[i] = malloc(strlen(envp[i]) + 1)) != NULL)
-            xastir_snprintf(environ[i],
-                sizeof(environ[i]),
+        if((local_environ[i] = malloc(strlen(envp[i]) + 1)) != NULL)
+            xastir_snprintf(local_environ[i],
+                strlen(envp[i])+1,
                 "%s",
                 envp[i]);
         }
-    
-        environ[i] = NULL;
     }
+    local_environ[i] = NULL;
 
     Argv = argv;
   
-    for(i = 0; envp[i] != NULL; i++) {
-        if((LastArgv + 1) == envp[i]) // Not sure if this conditional is needed
+    for(i = 0; argv[i] != NULL; i++) {
+        if((LastArgv + 1) == argv[i]) // Not sure if this conditional is needed
         LastArgv = envp[i] + strlen(envp[i]);
     }
 #ifdef __linux__
 #ifndef __LSB__
     // Pretty sure you don't need this either
+    old_progname = __progname;
+    old_progname_full = __progname_full;
     __progname = strdup("xastir");
     __progname_full = strdup(argv[0]);
 #endif  // __LSB__
 #endif  // __linux__
+    atexit(clear_proc_title);
 }
 
 
-void clear_proc_title(void)
-{
-  int i;
-  for(i = 0; environ[i] != NULL; i++) {
-    free(environ[i]);
-  }
-  free(environ);
-  environ = NULL;
-}
-
 void set_proc_title(char *fmt,...) {
     va_list msg;
     static char statbuf[8192];
@@ -882,7 +919,6 @@ void set_proc_title(char *fmt,...) {
     while(p < LastArgv)
         *p++ = '\0';
     Argv[1] = ((void *)0) ;
-    atexit(clear_proc_title);
 }
 
 
@@ -1051,19 +1087,24 @@ void TCP_Server(int argc, char *argv[], char *envp[]) {
             timestring,
             inet_ntoa(cli_addr.sin_addr));
  
+        if (pipe(p->to_child) < 0 || pipe(p->to_parent) < 0) {
+            fprintf(stderr,"x_spider: Can't create pipes\n");
+            if (p->to_child[1]) close(p->to_child[1]);
+            if (p->to_child[0]) close(p->to_child[0]);
+            free(p);    // Free the malloc'd memory.
+            p = NULL;
+            close(newsockfd);
+            goto finis;
+        }
+
+        // Indicate active connection!
+        p->active = 1;
+
         // Link it into the head of the chain.
         //
         p->next = pipe_head;
         pipe_head = p;
 
-        if (pipe(p->to_child) < 0 || pipe(p->to_parent) < 0) {
-            fprintf(stderr,"x_spider: Can't create pipes\n");
-            free(p);    // Free the malloc'd memory.
-	    p = NULL;
-            close(newsockfd);
-            goto finis;
-        }
-
         flag = 1;
 
         // Turn on the socket keepalive option
@@ -1083,8 +1124,9 @@ void TCP_Server(int argc, char *argv[], char *envp[]) {
             close(p->to_child[1]);
             close(p->to_parent[0]);
             close(p->to_parent[1]);
+            pipe_head = p->next;
             free(p);    // Free the malloc'd memory.
-	    p = NULL;
+            p = NULL;
             close(newsockfd);
             goto finis;
         }
@@ -1279,7 +1321,7 @@ fprintf(stderr, "Received datagram: %s", buf);
 
         // Copy the entire buffer so that we can modify it
         xastir_snprintf(buf2, sizeof(buf2), "%s", buf);
-        split_string(buf2, cptr, 10);
+        split_string(buf2, cptr, 10, ',');
 
         if (cptr[0] == NULL || cptr[0][0] == '\0') {    // callsign
             send_udp_nack(sock, from, fromlen);
@@ -1460,7 +1502,7 @@ int Fork_TCP_server(int argc, char *argv[], char *envp[]) {
     if (pipe(xastir_tcp_pipe->to_child) < 0 || pipe(xastir_tcp_pipe->to_parent) < 0) {
         fprintf(stderr,"x_spider: Can't create pipes\n");
         free(xastir_tcp_pipe);    // Free the malloc'd memory.
-	xastir_tcp_pipe = NULL;
+        xastir_tcp_pipe = NULL;
         return(0);
     }
  
@@ -1476,7 +1518,7 @@ int Fork_TCP_server(int argc, char *argv[], char *envp[]) {
         close(xastir_tcp_pipe->to_parent[0]);
         close(xastir_tcp_pipe->to_parent[1]);
         free(xastir_tcp_pipe);    // Free the malloc'd memory.
-	xastir_tcp_pipe = NULL;
+        xastir_tcp_pipe = NULL;
         return(0);
     }
     else if (childpid == 0) {
@@ -1523,7 +1565,7 @@ int Fork_TCP_server(int argc, char *argv[], char *envp[]) {
 //            fprintf(stderr,"Starting TCP_Server...\n");
 
             TCP_Server(argc, argv, envp);
- 
+
 //            fprintf(stderr,"TCP_Server process died.\n");
 //        }
     }
@@ -1579,7 +1621,7 @@ int Fork_UDP_server(int argc, char *argv[], char *envp[]) {
     if (pipe(xastir_udp_pipe->to_child) < 0 || pipe(xastir_udp_pipe->to_parent) < 0) {
         fprintf(stderr,"x_spider: Can't create pipes\n");
         free(xastir_udp_pipe);    // Free the malloc'd memory.
-	xastir_udp_pipe = NULL;
+        xastir_udp_pipe = NULL;
         return(0);
     }
  
@@ -1595,7 +1637,7 @@ int Fork_UDP_server(int argc, char *argv[], char *envp[]) {
         close(xastir_udp_pipe->to_parent[0]);
         close(xastir_udp_pipe->to_parent[1]);
         free(xastir_udp_pipe);    // Free the malloc'd memory.
-	xastir_udp_pipe = NULL;
+        xastir_udp_pipe = NULL;
         return(0);
     }
     else if (childpid == 0) {
@@ -1642,7 +1684,7 @@ int Fork_UDP_server(int argc, char *argv[], char *envp[]) {
 //            fprintf(stderr,"Starting UDP_Server...\n");
 
 	UDP_Server(argc, argv, envp);
- 
+
 	fprintf(stderr,"UDP_Server process died.\n");
 //        }
     }
