@@ -1,9 +1,9 @@
 /* -*- c-basic-offset: 4; indent-tabs-mode: nil -*-
- * $Id: xastir.h,v 1.60 2008/07/02 03:04:44 we7u Exp $
+ * $Id: xastir.h,v 1.64 2010/01/31 02:12:25 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2008  The Xastir Group
+ * Copyright (C) 2000-2010  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -103,7 +103,6 @@ extern void Send_message(Widget w, XtPointer clientData, XtPointer callData);
 extern void create_gc(Widget w);
 
 extern void Station_info(Widget w, XtPointer clientData, XtPointer calldata);
-extern void Window_Quit(Widget w, XtPointer client, XtPointer call);
 
 extern void fix_dialog_size(Widget w);
 extern void fix_dialog_vsize(Widget w);
@@ -141,6 +140,7 @@ extern int long_lat_grid;
 //extern Pixmap  pixmap_alerts;
 extern int map_color_levels;
 extern int map_labels;
+extern int map_lock_pan_zoom;
 extern int map_auto_maps;
 extern int auto_maps_skip_raster;
 extern time_t sec_remove;
